package com.kdanmobile.dragwebobject;

import android.graphics.PointF;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.bumptech.glide.Glide;

import butterknife.Bind;
import butterknife.ButterKnife;

public class MainActivity extends AppCompatActivity implements WebViewFragment.OnFragmentInteractionListener, TouchReceiveLayout.TouchReceiveInterface {

    @Bind(R.id.touch_receive_layout)
    protected TouchReceiveLayout touchReceiveLayout;

    @Bind(R.id.drag_layout)
    protected DragLayout dragLayout;

    @Bind(R.id.draw_layout)
    protected RelativeLayout drawerLayout;

    private View dragView;

    private int drawerWidth;

    private int drawerHeight;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        ButterKnife.bind(this);

        getSupportFragmentManager().beginTransaction().add(R.id.web_fragment, WebViewFragment.newInstance()).commit();

        touchReceiveLayout.setTouchReceiveInterface(this);

        drawerLayout.post(new Runnable() {
            @Override
            public void run() {
                drawerWidth = drawerLayout.getWidth();
                drawerHeight = drawerLayout.getHeight();
            }
        });
    }

    @Override
    public void onSelectText(String selectText) {
        TextView textView = new TextView(this);
        PointF touchDownPoint = dragLayout.getTouchDownPoint();
        if (touchDownPoint != null) {
            textView.setX(touchDownPoint.x);
            textView.setY(touchDownPoint.y);
        }
        dragLayout.addView(textView);

        textView.setText(selectText);
        dragView = textView;
    }

    @Override
    public void onClickWebImage(String imageSrc, int imageWidth, int imageHeight) {
        ImageView imageView = new ImageView(this);
        PointF touchDownPoint = dragLayout.getTouchDownPoint();
        if (touchDownPoint != null) {
            imageView.setX(touchDownPoint.x);
            imageView.setY(touchDownPoint.y);
        }
        dragLayout.addView(imageView);

        ViewGroup.LayoutParams layoutParams = imageView.getLayoutParams();
        layoutParams.width = imageWidth;
        layoutParams.height = imageHeight;
        imageView.setLayoutParams(layoutParams);
        Glide.with(this).load(imageSrc).into(imageView);
        dragView = imageView;
    }

    @Override
    public void onReceiveTouchMoveEvent(MotionEvent event) {
        if (dragView != null) {
            dragView.setX(event.getX() - dragView.getLayoutParams().width / 2);
            dragView.setY(event.getY() - dragView.getLayoutParams().height / 2);
        }
    }

    @Override
    public void onReceiveTouchUpEvent(MotionEvent event) {
        if (dragView != null) {
            dragLayout.removeAllViews();

            PointF touchUpPoint = new PointF(event.getX(), event.getY());
            if (touchUpPoint != null) {
                if (touchUpPoint.x < drawerHeight && touchUpPoint.y < drawerWidth) {
                    drawerLayout.addView(dragView);
                    dragView.setX(event.getX() + dragView.getLayoutParams().width / 2);
                    dragView.setY(event.getY() - dragView.getLayoutParams().height / 2);
                    dragView = null;
                }
            }
        }
    }


}
